@@ -6,12 +6,13 @@ from typing import List, Optional
 
 import srsly
 
+from genbase._version import __version__
 from genbase.data import import_data, train_test_split
 from genbase.decorator import add_callargs
 from genbase.internationalization import (LOCALE_MAP, get_locale, set_locale,
                                           translate_list, translate_string)
 from genbase.mixin import CaseMixin, SeedMixin
-from genbase.model import from_sklearn
+from genbase.model import import_model
 from genbase.ui import Render, is_interactive
 from genbase.utils import recursive_to_dict
 
@@ -203,6 +204,3 @@ class MetaInfo(Configurable):
 
     def _repr_html_(self) -> str:
         return self._renderer(self.to_config()).as_html(**self.renderargs) if is_interactive() else repr(self)
-
-
-__version__ = '0.1.18'
